.. _astrodynx.utils:

``astrodynx.utils``
====================

.. currentmodule:: astrodynx.utils

.. container:: module-header

   .. automodule:: astrodynx.utils
      :no-index:

.. container:: module-content

   .. rubric:: Coordinate Transformation Functions

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      rotmat3dx
      rotmat3dy
      rotmat3dz


.. container:: module-footer

   .. rubric:: Module Information

   **Full name:** ``astrodynx.utils``

   **Source:** `View source on GitHub <https://github.com/adxorg/astrodynx/blob/main/src/astrodynx/utils>`_
